# Code of Conduct

We follow the [Contributor Covenant](https://www.contributor-covenant.org/) Code of Conduct.

## Our Pledge
Be respectful, inclusive, and constructive.

## Our Standards
- Use welcoming language
- Be considerate of differing viewpoints
- Gracefully accept constructive criticism
- Focus on what is best for the community

## Enforcement
Report issues to the maintainers at **bazdalaz@gmail.com**.
